/* $Workfile: OtxTemuxD.h $   $Revision: 6 $    $Modtime: 1/25/11 5:46p $  */
#ifndef OTX_TEMUX_DEF_H
#define OTX_TEMUX_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxTemuxD

  Copyright (C) 2010-2011 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxTemuxD | Constants, Macros, and Types for the Temux SONET/SDH Functions

  @contents2
  OtxTemuxD.h |

  @index const enum struct type | OtxTemuxD

  @contents2
  OTX Temux SONET/SDH Device Constants, Macros, and Types |

  @head3 Enumerated Types  |

  @index enum | OtxTemuxD

  @head3 Struct Types |

  @index struct | OtxTemuxD

  @head3 Constants |

  @index const | OtxTemuxD

  @head3 Other Types |

  @index type | OtxTemuxD

*******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

#define OTX_TEMUX_MAX_LINK        4 // Temux supports up to 4 SONET/SDH links
#define OTX_TEMUX_MAX_STS1        3 // Temux supports up to 3 STS1
#define OTX_TEMUX_MAX_VTGROUP     7 // Temux supports up to 7 VT Group
#define OTX_TEMUX_MAX_TRIB       28 // Temux supports up to 28 tributaries
#define OTX_TEMUX_T1_TRIB        28 // Temux supports up to 28 T1 tributaries
#define OTX_TEMUX_E1_TRIB        21 // Temux supports up to 21 E1 tributaries
#define OTX_MAX_HWY_ENABLE_INDEX  3 // 3 OTX_UINT32 values are needed to define 
                                    // the enable for each one the ports highways 

/*******************************************************************************
  @enum 
    TEMUX Attributes
*******************************************************************************/
enum OtxTemuxAttributesE {
  OTX_ATTR_TEMUX_HWYS_MASK    = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_OCTETS) Read/Write. 
                                                   // <nl>Highway mask used to connect active highways within  
                                                   // the Temux device an array of 6 OTX_UINT32 values. The first 
                                                   // 3 value (index 0-2) are used to enable port 1 highways and last 3
                                                   // value in the array (index 3-5) are used to configure port 2
                                                   // highways. The Temux supports a maximum of 84 highways per port.
                                                   // The host interface may not be able to transfer all the highways
                                                   // and may only support a subset of them. This attribute allows the
                                                   // application to select which highway to transfer over the host
                                                   // interface. see <t OtxTemuxHighwayEnableS>
  OTX_ATTR_TEMUX_END          = OTX_ATTR_END + 1
};

typedef enum OtxTemuxAttributesE OtxTemuxAttributesE;


/*******************************************************************************
  @enum
    Event Codes

    Note that for line interfaces messages can have a different meaning 
    depending on whether the Line Interfaces (LIs) are configured to E1 
    or T1 mode and have seperate events.

*******************************************************************************/
enum OtxTemuxEventCodesE {
  OTX_TEMUX_EC_ING_LI_LOS,            // @emem SONET(SDH) LOS <e OtxEventDataS.m_nParam> =port
  OTX_TEMUX_EC_ING_LI_LOF,            // @emem SONET(SDH) LOF <e OtxEventDataS.m_nParam> =port
  OTX_TEMUX_EC_ING_LI_TIM,            // @emem SONET(SDH) Trace identifier mismatch <e OtxEventDataS.m_nParam> =port
  OTX_TEMUX_EC_ING_LI_SF,             // @emem SONET(SDH) Signal Failure <e OtxEventDataS.m_nParam> =port
  OTX_TEMUX_EC_ING_LI_SD,             // @emem SONET(SDH) Signal Degrade <e OtxEventDataS.m_nParam> =port
  OTX_TEMUX_EC_ING_LI_LAIS,           // @emem SONET(SDH) Alarm indication signal <e OtxEventDataS.m_nParam> =port
  OTX_TEMUX_EC_HOPP_TIM,              // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_TIU,              // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PERDI,            // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PRDI,             // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PPDI,             // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PUNEQ,            // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PPLM,             // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PPLU,             // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_SF,               // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_SD,               // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PAISC,             // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PLOPC,             // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PAIS,              // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PLOP,              // @emem SONET(SDH) 
  OTX_TEMUX_EC_TRIB_LOM,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_AIS,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_LOP,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_RDI,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_ERDI,             // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_PSLU,             // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_PSLM,             // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_UNEQ,             // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_PDI,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_TIM,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_TIU,              // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_SF,               // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_SD,               // @emem SONET(SDH) Tributary
                                      // <nl>For all PDH DS1/E1 <e OtxEventDataS.m_nParam> :
                                      // <nl>  Bits [7:0] port number one relative
                                      // <nl>  Bits [15:8] SPE number one relative
                                      // <nl>  Bits [23:16] Tributary number one relative
  OTX_TEMUX_EC_T1_AIS,                // @emem PDH DS1 AIS reflects the current state of the
                                      // integrated AIS alarm status. AIS is asserted when an
                                      // unframed all ones sequence has been received for 2.55 
                                      // seconds +/- 100 ms. AIS is removed 16.8 seconds +/- 500 ms
                                      // after the all ones pattern is removed.
  OTX_TEMUX_EC_T1_RED,                // @emem PDH DS1 red reflects the current state of the
                                      // integrated red alarm status. red is asserted when the
                                      // out-of-frame condition has existed for at least 2.55 seconds
                                      // +/- 40 ms. red is removed when the in frame condition has
                                      // existed for at least 16.6 seconds +/- 500 ms.
  OTX_TEMUX_EC_T1_YEL,                // @emem PDH DS1 yellow reflects the current state of
                                      // the integrated yellow alarm status. It is asserted when the
                                      // RAI signature has been received for 425 +/- 50 ms. yellow is
                                      // removed when the RAI signature has been absent for 425 +/- 50 ms.
                                      // Note: the RAI signature depends on the T1 framing format.
  OTX_TEMUX_EC_T1_COFA,               // @emem PDH DS1 new framing bit position determined during
                                      // frame search differs from the previous framing bit
  OTX_TEMUX_EC_T1_INF,                // @emem PDH DS1 loss of T1 framing 
  OTX_TEMUX_EC_E1_TS16AISD,           // @emem PDH E1 the incoming TS 16 data stream has a low zero-bit density.
                                      // TS16AISD is detected when the incoming TS16 signal has 3 or less zeroes
                                      // in each of 2 consecutive multi-frames.
  OTX_TEMUX_EC_E1_AIS,                // @emem PDH E1 an out of frame all-ones condition has persisted for 100 ms.
  OTX_TEMUX_EC_E1_RED,                // @emem PDH E1 an out of frame condition has persisted for 100 ms.
  OTX_TEMUX_EC_E1_AISD,               // @emem PDH E1 the incoming data stream has a low zero-bit density
                                      // for an interval specified by the AISC bit. When the AISC bit is
                                      // a logic 0, AISD is asserted when 512 bit periods have been received
                                      // with 2 or fewer zeros. The indication is cleared when a 512 bit period
                                      // is received with 3 or more zeros, or when the basic frame alignment is
                                      // found. When the AISC bit is a logic 1, AISD is asserted when each of two
                                      // consecutive 512 bit periods have been received with 2 or fewer zeros. 
                                      // The AISD bit is updated once every 512-bit period.
  OTX_TEMUX_EC_E1_RMAI,               // @emem PDH E1 the Y bit (bit 6 in time slot 16 in frame 0 of the
                                      // signaling multi-frames) has been a logic one for 3 consecutive
                                      // signaling multi-frames. The RMAI bit is updated every 16 frames.
                                      // The RMAI status is not updated while out of multi-frame alignment.
  OTX_TEMUX_EC_E1_RAI,                // @emem PDH E1 the A bit (bit 3 in time slot 0 of the non-frame
                                      // alignment signal frame) has been logic one for an interval specified
                                      // by the RAIC bit. When the RAIC bit is a logic 1, RAI is set when A=1
                                      // for 4 or more consecutive intervals. When the RAIC bit is a logic 0,
                                      // RAI is set upon reception of any A=1. The RAI output is updated every
                                      // two frames. The RAI status is not updated while out of frame alignment.
  OTX_TEMUX_EC_E1_CFEBE,              // @emem PDH E1 CFEBE bit reflects the current state of the continuous
                                      // FEBE indicator; the CRC error (E bit) is set high on more than 990
                                      // occasions in each second (out of 1000 possibleoccasions) for the last
                                      // 5 consecutive seconds.
  OTX_TEMUX_EC_E1_RAICCRC,            // @emem PDH E1 The RAICCRC bit reflects the current state of the RAI
                                      // and continuous CRC indicator. RAICCRC is asserted when the remote
                                      // alarm (A bit) is set high and the CRC error (E bit) is set low for
                                      // a period of 10 ms. Note the RAICCRC status is not updated while out
                                      // of CRC multi-frame alignment.
  OTX_TEMUX_EC_E1_OOOF,               // @emem PDH E1 offline framer in the CRC multi-frame find procedure is searching for frame alignment
  OTX_TEMUX_EC_E1_INCMF,              // @emem PDH E1 INCMF loss of framing with the CRC multi-frame alignment
  OTX_TEMUX_EC_E1_INSMF,              // @emem PDH E1 INSMF loss of framing with the signaling multi-frame alignment
  OTX_TEMUX_EC_E1_INF,                // @emem PDH E1 loss of framing 
                                      // <nl>For all PDH E1T1 <e OtxEventDataS.m_nParam> :
                                      // <nl>  Bits [31:0] port number one relative
  OTX_TEMUX_EC_E1T1_SLP_R,            // @emem PDH E1T1 frame slip elastic buffer receive  
  OTX_TEMUX_EC_E1T1_SLP_T,            // @emem PDH E1T1 frame slip elastic buffer transmit  
  OTX_TEMUX_EC_E1T1_SLP_CAS,          // @emem PDH E1T1 frame slip elastic CAS buffer  
  OTX_TEMUX_EC_DS3_RED,               // @emem PDH 
  OTX_TEMUX_EC_DS3_CBIT,              // @emem PDH 
  OTX_TEMUX_EC_DS3_RDI,               // @emem PDH 
  OTX_TEMUX_EC_DS3_IDL,               // @emem PDH 
  OTX_TEMUX_EC_DS3_AIS,               // @emem PDH 
  OTX_TEMUX_EC_DS3_OOF,               // @emem PDH 
  OTX_TEMUX_EC_DS3_LOS,               // @emem PDH 
  OTX_TEMUX_EC_DS3_LOF,               // @emem PDH 
  OTX_TEMUX_EC_E3_LOS,                // @emem PDH 
  OTX_TEMUX_EC_E3_OOF,                // @emem PDH 
  OTX_TEMUX_EC_E3_RDI_RAI,            // @emem PDH 
  OTX_TEMUX_EC_E3_REI,                // @emem PDH 
  OTX_TEMUX_EC_E3_PTYPE0,             // @emem PDH 
  OTX_TEMUX_EC_E3_PTYPE1,             // @emem PDH 
  OTX_TEMUX_EC_E3_PTYPE2,             // @emem PDH 
  OTX_TEMUX_EC_E3_TIMEMK,             // @emem PDH 
  OTX_TEMUX_EC_E3_NETUSE,             // @emem PDH 
  OTX_TEMUX_EC_E3_LOF,                // @emem PDH 
  OTX_TEMUX_EC_E3_AIS,                // @emem PDH 
  OTX_TEMUX_EC_M13_RED,               // @emem PDH 
  OTX_TEMUX_EC_M13_FERF,              // @emem PDH 
  OTX_TEMUX_EC_M13_RES,               // @emem PDH 
  OTX_TEMUX_EC_M13_AIS,               // @emem PDH 
  OTX_TEMUX_EC_M13_OOF,               // @emem PDH 
  OTX_TEMUX_EC_QUEUE_FULL_EVENT_LOST, // @emem The event queue was full with at least one event lost. The  
                                      // <nl> <e OtxEventDataS.m_nParam> field contains the number of events lost. 

  OTX_TEMUX_END_OF_EVENT_CODES

};
typedef enum OtxTemuxEventCodesE OtxTemuxEventCodesE;

/*******************************************************************************
  @enum 
    Temux highway enable mask. The Temux device supports up to 84 highways per
    port, each highway has 32 timeslots. The following defines are used to enable
    a highway and allow the data to be transferred by the Temux device. The
    highways that are not enabled will not be transfer data and the memory 
    buffer assigned to this highway is not used.

    The enable bit for each of the highways is devided between 3 OTX_UINT32 
    values. Setting the bit enables the highway. If the bit is cleared no 
    data is transferred for that highway.
    
    Highways 0-63 are used with E1 and T1 data transfers and highways 64-83 
    are used for T1 data (OC-3).The third OTX_UINT32 should not be used with
    E1 data transfers (OTX_TEMUX_E1) and should be 0.
*******************************************************************************/
enum OtxTemuxHighwayEnableMaskE {
  OTX_TEMUX_T1E1_HWY_DISABLE   = 0x00000000, // @emem Highway Disable

  OTX_TEMUX_UINT_0_T1E1_HWY_0  = 0x00000001, // @emem OTX_UINT32 0, highway  0
  OTX_TEMUX_UINT_0_T1E1_HWY_1  = 0x00000002, // @emem OTX_UINT32 0, highway  1
  OTX_TEMUX_UINT_0_T1E1_HWY_2  = 0x00000004, // @emem OTX_UINT32 0, highway  2
  OTX_TEMUX_UINT_0_T1E1_HWY_3  = 0x00000008, // @emem OTX_UINT32 0, highway  3
  OTX_TEMUX_UINT_0_T1E1_HWY_4  = 0x00000010, // @emem OTX_UINT32 0, highway  4
  OTX_TEMUX_UINT_0_T1E1_HWY_5  = 0x00000020, // @emem OTX_UINT32 0, highway  5
  OTX_TEMUX_UINT_0_T1E1_HWY_6  = 0x00000040, // @emem OTX_UINT32 0, highway  6
  OTX_TEMUX_UINT_0_T1E1_HWY_7  = 0x00000080, // @emem OTX_UINT32 0, highway  7
  OTX_TEMUX_UINT_0_T1E1_HWY_8  = 0x00000100, // @emem OTX_UINT32 0, highway  8
  OTX_TEMUX_UINT_0_T1E1_HWY_9  = 0x00000200, // @emem OTX_UINT32 0, highway  9
  OTX_TEMUX_UINT_0_T1E1_HWY_10 = 0x00000400, // @emem OTX_UINT32 0, highway 10
  OTX_TEMUX_UINT_0_T1E1_HWY_11 = 0x00000800, // @emem OTX_UINT32 0, highway 11
  OTX_TEMUX_UINT_0_T1E1_HWY_12 = 0x00001000, // @emem OTX_UINT32 0, highway 12
  OTX_TEMUX_UINT_0_T1E1_HWY_13 = 0x00002000, // @emem OTX_UINT32 0, highway 13
  OTX_TEMUX_UINT_0_T1E1_HWY_14 = 0x00004000, // @emem OTX_UINT32 0, highway 14
  OTX_TEMUX_UINT_0_T1E1_HWY_15 = 0x00008000, // @emem OTX_UINT32 0, highway 15
  OTX_TEMUX_UINT_0_T1E1_HWY_16 = 0x00010000, // @emem OTX_UINT32 0, highway 16
  OTX_TEMUX_UINT_0_T1E1_HWY_17 = 0x00020000, // @emem OTX_UINT32 0, highway 17
  OTX_TEMUX_UINT_0_T1E1_HWY_18 = 0x00040000, // @emem OTX_UINT32 0, highway 18
  OTX_TEMUX_UINT_0_T1E1_HWY_19 = 0x00080000, // @emem OTX_UINT32 0, highway 19
  OTX_TEMUX_UINT_0_T1E1_HWY_20 = 0x00100000, // @emem OTX_UINT32 0, highway 20
  OTX_TEMUX_UINT_0_T1E1_HWY_21 = 0x00200000, // @emem OTX_UINT32 0, highway 21
  OTX_TEMUX_UINT_0_T1E1_HWY_22 = 0x00400000, // @emem OTX_UINT32 0, highway 22
  OTX_TEMUX_UINT_0_T1E1_HWY_23 = 0x00800000, // @emem OTX_UINT32 0, highway 23
  OTX_TEMUX_UINT_0_T1E1_HWY_24 = 0x01000000, // @emem OTX_UINT32 0, highway 24
  OTX_TEMUX_UINT_0_T1E1_HWY_25 = 0x02000000, // @emem OTX_UINT32 0, highway 25
  OTX_TEMUX_UINT_0_T1E1_HWY_26 = 0x04000000, // @emem OTX_UINT32 0, highway 26
  OTX_TEMUX_UINT_0_T1E1_HWY_27 = 0x08000000, // @emem OTX_UINT32 0, highway 27
  OTX_TEMUX_UINT_0_T1E1_HWY_28 = 0x10000000, // @emem OTX_UINT32 0, highway 28
  OTX_TEMUX_UINT_0_T1E1_HWY_29 = 0x20000000, // @emem OTX_UINT32 0, highway 29
  OTX_TEMUX_UINT_0_T1E1_HWY_30 = 0x40000000, // @emem OTX_UINT32 0, highway 30
  OTX_TEMUX_UINT_0_T1E1_HWY_31 = 0x80000000, // @emem OTX_UINT32 0, highway 31

  OTX_TEMUX_UINT_1_T1E1_HWY_32 = 0x00000001, // @emem OTX_UINT32 1, highway 32
  OTX_TEMUX_UINT_1_T1E1_HWY_33 = 0x00000002, // @emem OTX_UINT32 1, highway 33
  OTX_TEMUX_UINT_1_T1E1_HWY_34 = 0x00000004, // @emem OTX_UINT32 1, highway 34
  OTX_TEMUX_UINT_1_T1E1_HWY_35 = 0x00000008, // @emem OTX_UINT32 1, highway 35
  OTX_TEMUX_UINT_1_T1E1_HWY_36 = 0x00000010, // @emem OTX_UINT32 1, highway 36
  OTX_TEMUX_UINT_1_T1E1_HWY_37 = 0x00000020, // @emem OTX_UINT32 1, highway 37
  OTX_TEMUX_UINT_1_T1E1_HWY_38 = 0x00000040, // @emem OTX_UINT32 1, highway 38
  OTX_TEMUX_UINT_1_T1E1_HWY_39 = 0x00000080, // @emem OTX_UINT32 1, highway 39
  OTX_TEMUX_UINT_1_T1E1_HWY_40 = 0x00000100, // @emem OTX_UINT32 1, highway 40
  OTX_TEMUX_UINT_1_T1E1_HWY_41 = 0x00000200, // @emem OTX_UINT32 1, highway 41
  OTX_TEMUX_UINT_1_T1E1_HWY_42 = 0x00000400, // @emem OTX_UINT32 1, highway 42
  OTX_TEMUX_UINT_1_T1E1_HWY_43 = 0x00000800, // @emem OTX_UINT32 1, highway 43
  OTX_TEMUX_UINT_1_T1E1_HWY_44 = 0x00001000, // @emem OTX_UINT32 1, highway 44
  OTX_TEMUX_UINT_1_T1E1_HWY_45 = 0x00002000, // @emem OTX_UINT32 1, highway 45
  OTX_TEMUX_UINT_1_T1E1_HWY_46 = 0x00004000, // @emem OTX_UINT32 1, highway 46
  OTX_TEMUX_UINT_1_T1E1_HWY_47 = 0x00008000, // @emem OTX_UINT32 1, highway 47
  OTX_TEMUX_UINT_1_T1E1_HWY_48 = 0x00010000, // @emem OTX_UINT32 1, highway 48
  OTX_TEMUX_UINT_1_T1E1_HWY_49 = 0x00020000, // @emem OTX_UINT32 1, highway 49
  OTX_TEMUX_UINT_1_T1E1_HWY_50 = 0x00040000, // @emem OTX_UINT32 1, highway 50
  OTX_TEMUX_UINT_1_T1E1_HWY_51 = 0x00080000, // @emem OTX_UINT32 1, highway 51
  OTX_TEMUX_UINT_1_T1E1_HWY_52 = 0x00100000, // @emem OTX_UINT32 1, highway 52
  OTX_TEMUX_UINT_1_T1E1_HWY_53 = 0x00200000, // @emem OTX_UINT32 1, highway 53
  OTX_TEMUX_UINT_1_T1E1_HWY_54 = 0x00400000, // @emem OTX_UINT32 1, highway 54
  OTX_TEMUX_UINT_1_T1E1_HWY_55 = 0x00800000, // @emem OTX_UINT32 1, highway 55
  OTX_TEMUX_UINT_1_T1E1_HWY_56 = 0x01000000, // @emem OTX_UINT32 1, highway 56
  OTX_TEMUX_UINT_1_T1E1_HWY_57 = 0x02000000, // @emem OTX_UINT32 1, highway 57
  OTX_TEMUX_UINT_1_T1E1_HWY_58 = 0x04000000, // @emem OTX_UINT32 1, highway 58
  OTX_TEMUX_UINT_1_T1E1_HWY_59 = 0x08000000, // @emem OTX_UINT32 1, highway 59
  OTX_TEMUX_UINT_1_T1E1_HWY_60 = 0x10000000, // @emem OTX_UINT32 1, highway 60
  OTX_TEMUX_UINT_1_T1E1_HWY_61 = 0x20000000, // @emem OTX_UINT32 1, highway 61
  OTX_TEMUX_UINT_1_T1E1_HWY_62 = 0x40000000, // @emem OTX_UINT32 1, highway 62
  OTX_TEMUX_UINT_1_T1E1_HWY_63 = 0x80000000, // @emem OTX_UINT32 1, highway 63

  OTX_TEMUX_UINT_2_T1_HWY_64   = 0x00000001, // @emem OTX_UINT32 2, highway 64
  OTX_TEMUX_UINT_2_T1_HWY_65   = 0x00000002, // @emem OTX_UINT32 2, highway 65
  OTX_TEMUX_UINT_2_T1_HWY_66   = 0x00000004, // @emem OTX_UINT32 2, highway 66
  OTX_TEMUX_UINT_2_T1_HWY_67   = 0x00000008, // @emem OTX_UINT32 2, highway 67
  OTX_TEMUX_UINT_2_T1_HWY_68   = 0x00000010, // @emem OTX_UINT32 2, highway 68
  OTX_TEMUX_UINT_2_T1_HWY_69   = 0x00000020, // @emem OTX_UINT32 2, highway 69
  OTX_TEMUX_UINT_2_T1_HWY_70   = 0x00000040, // @emem OTX_UINT32 2, highway 70
  OTX_TEMUX_UINT_2_T1_HWY_71   = 0x00000080, // @emem OTX_UINT32 2, highway 71
  OTX_TEMUX_UINT_2_T1_HWY_72   = 0x00000100, // @emem OTX_UINT32 2, highway 72
  OTX_TEMUX_UINT_2_T1_HWY_73   = 0x00000200, // @emem OTX_UINT32 2, highway 73
  OTX_TEMUX_UINT_2_T1_HWY_74   = 0x00000400, // @emem OTX_UINT32 2, highway 74
  OTX_TEMUX_UINT_2_T1_HWY_75   = 0x00000800, // @emem OTX_UINT32 2, highway 75
  OTX_TEMUX_UINT_2_T1_HWY_76   = 0x00001000, // @emem OTX_UINT32 2, highway 76
  OTX_TEMUX_UINT_2_T1_HWY_77   = 0x00002000, // @emem OTX_UINT32 2, highway 77
  OTX_TEMUX_UINT_2_T1_HWY_78   = 0x00004000, // @emem OTX_UINT32 2, highway 78
  OTX_TEMUX_UINT_2_T1_HWY_79   = 0x00008000, // @emem OTX_UINT32 2, highway 79
  OTX_TEMUX_UINT_2_T1_HWY_80   = 0x00010000, // @emem OTX_UINT32 2, highway 80
  OTX_TEMUX_UINT_2_T1_HWY_81   = 0x00020000, // @emem OTX_UINT32 2, highway 81
  OTX_TEMUX_UINT_2_T1_HWY_82   = 0x00040000, // @emem OTX_UINT32 2, highway 82
  OTX_TEMUX_UINT_2_T1_HWY_83   = 0x00080000, // @emem OTX_UINT32 2, highway 83

};
typedef enum OtxTemuxHighwayEnableMaskE OtxTemuxHighwayEnableMaskE;

/*******************************************************************************
  @struct 
    Temux highway enable used by the OtxTemuxAttributesE with the attribute
    OTX_ATTR_TEMUX_HWYS_MASK. The OtxTemuxHighwayEnableS stucture is used to 
    enable a subset of the available highways within the Temux. The host 
    interface device may not be able to transfer all highways. The highway 
    enable mask allows the application to select the highway to be transferred.
    See OtxTemuxHighwayEnableMaskE for individual highway enable bits.
    The number of ports (links) supported is board dependent 

  @xref
    <e OtxTemuxAttributesE.OTX_ATTR_TEMUX_HWYS_MASK>
    <e OtxTemuxHighwayEnableMaskE.OTX_TEMUX_UINT_0_T1E1_HWY_0>
*******************************************************************************/
struct OtxTemuxHighwayEnableS {
  OtxTemuxHighwayEnableMaskE eHwyMask[OTX_TEMUX_MAX_LINK][OTX_MAX_HWY_ENABLE_INDEX]; // @field Temux Highway enable mask
  OTX_UINT32 nMaxHwys; // @field maximum number of highways supported by data transfer
};
typedef struct OtxTemuxHighwayEnableS OtxTemuxHighwayEnableS;

/*******************************************************************************
  @enum 
    Temux interface 
*******************************************************************************/
enum OtxTemuxInterfaceE {
  OTX_TEMUX_INTERFACE_SBI    = 0,  // @emem SBI interface
  OTX_TEMUX_INTERFACE_HMVIP  = 1   // @emem HMVIP interface
};
typedef enum OtxTemuxInterfaceE OtxTemuxInterfaceE;

/*******************************************************************************
  @enum 
    Temux device configuration setup used to configure the entire device.
    Configuration option 0 is for user defined configuration.

  @xref
    <f OtxTemuxDeviceCfg>

*******************************************************************************/
enum OtxTemuxDevConfigureE {
  OTX_TEMUX_DEVICE_DEFAULT = 1,    // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 4 x VT-1.5
                                   // <nl> Each VT-1.5 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format and is loop timed to CTCLK
                                   // <nl> HMVIP System Interface.

  OTX_TEMUX_DS3M13CFG ,            // @emem 12 DS3 Links - Internally timed
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 28 ESF T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1VT15STS3CFG ,        // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 4 x VT-1.5
                                   // <nl> Each VT-1.5 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally 
                                   // timed to CTCLK.

  OTX_TEMUX_T1VT2STS3CFG ,         // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 3 x VT-2
                                   // <nl> Each VT-2 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_E1VT2STS3CFG ,         // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 3 x VT-2
                                   // <nl> Each VT-2 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_DS3G747CFG ,           // @emem 12 DS3 Links - Internally timed
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 21 Standard E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU11AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU12AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_E1TU12AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU11AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU12AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_E1TU12AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU11AU3STM4CFG ,     // @emem 1 x STM-4 Working Links - Internally timed
                                   // <nl> Each STM-4 has the following mapping:
                                   // <nl> STM-4 >> 4 x AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has unframed framing format.
                                   // <nl> For SBI System Interface, Timing Information for T1
                                   // <nl> tributaries are from the System Side Interface.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // <nl> timed to CTCLK.

  OTX_TEMUX_E1TU12AU4STM4CFG ,     // @emem 1 x STM-4 Working Links - Internally timed
                                   // <nl> Each STM-4 has the following mapping:
                                   // <nl> STM-4 >> 4 x AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has unframed framing format.
                                   // <nl> For SBI System Interface, Timing Information for E1
                                   // <nl> tributaries are from the System Side Interface.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // <nl> timed to CTCLK.

  OTX_TEMUX_T1TU11AU4STM4CFG ,     // @emem 1 x STM-4 Working Links - Internally timed
                                   // <nl> Each STM-4 has the following mapping:
                                   // <nl> STM-4 >> 4 x AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_DS3UNCHANNELIZEDCFG ,  // @emem 12 DS3 Links - Flow through timing 
                                   // <nl> using link rate data from SBI system 
                                   // <nl> interface. Each DS3 has C bit framing
                                   // <nl> System side interface is SBI Bus

  OTX_TEMUX_DS3M13AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> TU-3 >> VC-3 >> C3
                                   // <nl> Each C3 has DS3 payload.
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 28 ESF T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 
                                   // <nl> tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, 
                                   // <nl> T1 tributaries are internally
                                   // <nl> timed to CTCLK.

  OTX_TEMUX_DS3M13AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> C-3
                                   // <nl> Each C3 has DS3 payload.
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 28 ESF T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 
                                   // <nl> tributaries are loop timed. For 
                                   // <nl> HMVIP System Interface, T1 tributaries 
                                   // <nl> are internally timed to CTCLK.

  OTX_TEMUX_DS3UNCHAU3STM1CFG ,    // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> C-3
                                   // <nl> Each C3 has DS3 payload.
                                   // <nl> Each DS3 Uses - Flow through timing 
                                   // <nl> using link rate data from SBI system 
                                   // <nl> interface. Each DS3 has C bit framing
                                   // <nl> System side interface is SBI Bus

  OTX_TEMUX_T1VT15STS3LPTIMINGCFG // @emem 4 x OC-3 Working Links - Loop timed
                                  // <nl> Each OC-3 has the following mapping:
                                  // <nl>    OC-3 >> STS-3 >> 3 x STS-1
                                  // <nl> Each STS-1 has the following mapping:
                                  // <nl>    STS-1 >> 7 x VT-Group
                                  // <nl> Each VT-Group has the following mapping:
                                  // <nl>    VT-Group >> 4 x VT-1.5
                                  // <nl> Each VT-1.5 contains a bit asynchronously 
                                  // <nl> mapped T1 each T1 has ESF framing format.
                                  // <nl> For SBI System Interface, T1 tributaries 
                                  // <nl> are loop timed. For HMVIP System Interface, 
                                  // <nl> T1 tributaries are internally timed to CTCLK. 

};
typedef enum OtxTemuxDevConfigureE OtxTemuxDevConfigureE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for used to set the link to the
    OC-12/STM-4 payload is concatenated (sts12Concatenation) and an OC-3/STM-1
    or STS-3/AUG-1 payload is concatenated (sts3Concatenation).

  @xref
    <f OtxTemuxSonetPayloadCfg>
    <t OtxTemuxSts12ConcatE>

******************************************************************************/
enum OtxTemuxSts3ConcatE {
  OTX_TEMUX_3_STS1  = 0,  // @emem 3 x STS-1/AU-3
  OTX_TEMUX_STS3    = 1   // @emem STS-3c/AU4
};
typedef enum OtxTemuxSts3ConcatE OtxTemuxSts3ConcatE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for used to set the link to the
    OC-12/STM-4 payload is concatenated (sts12Concatenation) and an OC-3/STM-1
    or STS-3/AUG-1 payload is concatenated (sts3Concatenation).

  @xref
    <f OtxTemuxSonetPayloadCfg>
    <t OtxTemuxSts3ConcatE>

******************************************************************************/
enum OtxTemuxSts12ConcatE {
  OTX_TEMUX_4_STS3  = 0,  // @emem 4 x STS-3/AUG-1
  OTX_TEMUX_STS12   = 1   // @emem STS-12c/AU4-4c
};
typedef enum OtxTemuxSts12ConcatE OtxTemuxSts12ConcatE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration destination port

  @xref
    <f OtxTemuxStsiDestPortCfg>

*******************************************************************************/
enum OtxTemuxDestPortE {
  OTX_TEMUX_DEST_PORT_HOPP    = 0,  // @emem HOPP Receive
  OTX_TEMUX_DEST_PORT_ESSI_W  = 1,  // @emem ESSI Working Transmit
  OTX_TEMUX_DEST_PORT_ESSI_P  = 2,  // @emem ESSI Protect Transmit
  OTX_TEMUX_DEST_PORT_OC3_12  = 3   // @emem 4 x OC-3 or OC-12 Transmit
};
typedef enum OtxTemuxDestPortE OtxTemuxDestPortE;


/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration source port.
      STSI timeslots used for each STS-3
    
      0xA0 - timeslot 1, 5, 9
      0xA1 - timeslot 2, 6, 10
      0xA2 - timeslot 3, 7, 11
      0xA3 - timeslot 4, 8, 12
    
      where A is the STSI number

  @xref
    <f OtxTemuxStsiDestPortCfg>

*******************************************************************************/
enum OtxTemuxSrcPortE {
  OTX_TEMUX_SRC_OC3_00    = 0x00, // @emem Rx OC-3 #1/Rx OC-12 STS-3 #1
  OTX_TEMUX_SRC_OC3_01    = 0x01, // @emem Rx OC-3 #2/Rx OC-12 STS-3 #2
  OTX_TEMUX_SRC_OC3_02    = 0x02, // @emem Rx OC-3 #3/Rx OC-12 STS-3 #3
  OTX_TEMUX_SRC_OC3_03    = 0x03, // @emem Rx OC-3 #4/Rx OC-12 STS-3 #4
  OTX_TEMUX_SRC_ESSI_10    = 0x10, // @emem Rx ESSI Work STS-3 #1
  OTX_TEMUX_SRC_ESSI_11    = 0x11, // @emem Rx ESSI Work STS-3 #2
  OTX_TEMUX_SRC_ESSI_12    = 0x12, // @emem Rx ESSI Work STS-3 #3
  OTX_TEMUX_SRC_ESSI_13    = 0x13, // @emem Rx ESSI Work STS-3 #4
  OTX_TEMUX_SRC_ESSI_20    = 0x20, // @emem Rx ESSI Protect STS-3 #1
  OTX_TEMUX_SRC_ESSI_21    = 0x21, // @emem Rx ESSI Protect STS-3 #2
  OTX_TEMUX_SRC_ESSI_22    = 0x22, // @emem Rx ESSI Protect STS-3 #3
  OTX_TEMUX_SRC_ESSI_23    = 0x23, // @emem Rx ESSI Protect STS-3 #4
  OTX_TEMUX_SRC_HOPP_30    = 0x30, // @emem Tx HOPP STS-3 #1
  OTX_TEMUX_SRC_HOPP_31    = 0x31, // @emem Tx HOPP STS-3 #2
  OTX_TEMUX_SRC_HOPP_32    = 0x32, // @emem Tx HOPP STS-3 #3
  OTX_TEMUX_SRC_HOPP_33    = 0x33  // @emem Tx HOPP STS-3 #4
};
typedef enum OtxTemuxSrcPortE OtxTemuxSrcPortE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration MSU telecombus switching type

  @xref
    <f OtxTemuxMsuCfg>

*******************************************************************************/
enum OtxTemuxBlockTypeE {
  OTX_TEMUX_MSU_TYPE_RMSU    = 0, // @emem RMSU
  OTX_TEMUX_MSU_TYPE_TMSU    = 1  // @emem TMSU
};
typedef enum OtxTemuxBlockTypeE OtxTemuxBlockTypeE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration MSU telecombus switching mode

  @xref
    <f OtxTemuxMsuCfg>

*******************************************************************************/
enum OtxTemuxBlockModeE {
  OTX_TEMUX_MSU_MODE_SWITCH  = 0, // @emem Telecombus switching
  OTX_TEMUX_MSU_MODE_BYPASS  = 1  // @emem Bypass
};
typedef enum OtxTemuxBlockModeE OtxTemuxBlockModeE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration physical interface used

  @xref
    <f OtxTemuxSonetIntfCfg>

*******************************************************************************/
enum OtxTemuxIntfModeE {
  OTX_TEMUX_INTF_MODE_OC3_STM1    = 0, // @emem up to 4 x OC-3/STM-1
  OTX_TEMUX_INTF_MODE_1_OC12_STM4 = 1  // @emem one OC-12/STM-4
};
typedef enum OtxTemuxIntfModeE OtxTemuxIntfModeE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration link source

  @xref
    <f OtxTemuxSonetLinkCfg>

*******************************************************************************/
enum OtxTemuxLinkSrcE {
  OTX_TEMUX_LINK_WORKING  = 0, // @emem Working
  OTX_TEMUX_LINK_PROTECT  = 1  // @emem Protect
};
typedef enum OtxTemuxLinkSrcE OtxTemuxLinkSrcE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration link source

  @xref
    <f OtxTemuxSonetDataPathCfg>

*******************************************************************************/
enum OtxTemuxDataLinkSrcE {
  OTX_TEMUX_DATALINK_PROTECT  = 0, // @emem Protect
  OTX_TEMUX_DATALINK_WORKING  = 1  // @emem Working
};
typedef enum OtxTemuxDataLinkSrcE OtxTemuxDataLinkSrcE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration link clock source

    The internal link clock source is defined by <f OtxBrdSetClocks>) 
    board clock source provided for the Temux device.


  @xref
    <f OtxTemuxSonetTimingCfg>

******************************************************************************/
enum OtxTemuxClockSrcE {
  OTX_TEMUX_CLOCK_INTERNAL = 0,   // @emem Link internal timing
  OTX_TEMUX_CLOCK_LOOP     = 1    // @emem Link loop timing
};
typedef enum OtxTemuxClockSrcE OtxTemuxClockSrcE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-12 payload

  @xref
    <f OtxTemuxSts12PayloadCfg>

******************************************************************************/
enum OtxTemuxSts12PayloadE {
  OTX_TEMUX_STS_12   = 0,   // @emem STS-12c/AU4-4c
  OTX_TEMUX_4_STS_3  = 1    // @emem Four x STS-3/AUG-1
};
typedef enum OtxTemuxSts12PayloadE OtxTemuxSts12PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-3 payload

  @xref
    <f OtxTemuxSts3PayloadCfg>

******************************************************************************/
enum OtxTemuxSts3PayloadE {
  OTX_TEMUX_STS_3   = 0,   // @emem STS-3c/AU-4
  OTX_TEMUX_3_STS_1 = 1    // @emem Three x STS-1/AU-3
};
typedef enum OtxTemuxSts3PayloadE OtxTemuxSts3PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-3C payload

  @xref
    <f OtxTemuxSts3cPayloadCfg>

******************************************************************************/
enum OtxTemuxSts3cPayloadE {
  OTX_TEMUX_STS_3C   = 0,   // @emem C-4
  OTX_TEMUX_3C_STS_1 = 1    // @emem Three x TUG-3
};
typedef enum OtxTemuxSts3cPayloadE OtxTemuxSts3cPayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-1 payload

  @xref
    <f OtxTemuxSts1PayloadCfg>

******************************************************************************/
enum OtxTemuxSts1PayloadE {
  OTX_TEMUX_STS_1      = 0,   // @emem C-3
  OTX_TEMUX_7_VT_GROUP = 1    // @emem Seven x VT-Group
};
typedef enum OtxTemuxSts1PayloadE OtxTemuxSts1PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for TUG-3 payload

  @xref
    <f OtxTemuxTug3PayloadCfg>

******************************************************************************/
enum OtxTemuxTug3PayloadE {
  OTX_TEMUX_TU_3      = 0,   // @emem TU-3 demapped to C-3
  OTX_TEMUX_7_TUG_2   = 1    // @emem Seven x TUG-2
};
typedef enum OtxTemuxTug3PayloadE OtxTemuxTug3PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for TUG-2 payload

  @xref
    <f OtxTemuxTug2PayloadCfg>

******************************************************************************/
enum OtxTemuxTug2PayloadE {
  OTX_TEMUX_TU_12      = 0,   // @emem TU-12
  OTX_TEMUX_TU_11      = 1    // @emem TU-11
};
typedef enum OtxTemuxTug2PayloadE OtxTemuxTug2PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for 
    VT-Group payload, virtual tributaries (VT)

  @xref
    <f OtxTemuxVtGroupPayloadCfg>
    <f OtxTemuxMapperTribCfg>

******************************************************************************/
enum OtxTemuxVtTypeE {
  OTX_TEMUX_VT_2       = 0,   // @emem VT-2   E1
  OTX_TEMUX_VT_15      = 1    // @emem VT-1.5 T1
};
typedef enum OtxTemuxVtTypeE OtxTemuxVtTypeE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for TVPTA bypassing

  @xref
    <f OtxTemuxTvtpaBypassCfg>

******************************************************************************/
enum OtxTemuxBypassE {
  OTX_TEMUX_BYPASSED      = 0,   // @emem bypassed 
  OTX_TEMUX_NOT_BYPASSED  = 1    // @emem not bypassed
};
typedef enum OtxTemuxBypassE OtxTemuxBypassE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for system side interface
    (System interface Mode of Operation)

  @xref
    <f OtxTemuxSysIfModeCfg>
    <f OtxTemuxE1T1SpeCfg>

******************************************************************************/
enum OtxTemuxSysIfModeE {
  OTX_TEMUX_SBI    = 0,   // @emem SBI  
  OTX_TEMUX_SBITR  = 1,   // @emem SBI-TR
  OTX_TEMUX_HMVIP  = 2    // @emem HMVIP
};
typedef enum OtxTemuxSysIfModeE OtxTemuxSysIfModeE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for SPE source

  @xref
    <f OtxTemuxMapperSpeCfg>

******************************************************************************/
enum OtxTemuxMapSpeSrcE {
  OTX_TEMUX_T1E1  = 0,  // @emem T1E1 subsystem  
  OTX_TEMUX_DS3E3 = 1   // @emem DS3E3 subsystem
};
typedef enum OtxTemuxMapSpeSrcE OtxTemuxMapSpeSrcE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of T1/E1 tributary mapping 

  @xref
    <f OtxTemuxMapperTribCfg>
    <f OtxTemuxE1T1EgressTribTimingCfg>

******************************************************************************/
enum OtxTemuxMapTribModeE {
  OTX_TEMUX_BIT_ASYN  = 0,  // @emem bit asynchronous  
  OTX_TEMUX_BYTE_SYNC = 1,  // @emem byte synchronous
  OTX_TEMUX_TVT       = 2   // @emem Transparent Virtual Tributary
};
typedef enum OtxTemuxMapTribModeE OtxTemuxMapTribModeE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of PDH tributary type 

  @xref
    <f OtxTemuxMapperTribCfg>
    <f OtxTemuxMx13SpeCfg>
    <f OtxTemuxE1T1SpeCfg>

******************************************************************************/
enum OtxTemuxPhdTribE {
  OTX_TEMUX_T1  = 0,  // @emem T1  
  OTX_TEMUX_E1  = 1   // @emem E1
};
typedef enum OtxTemuxPhdTribE OtxTemuxPhdTribE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for DS3 frame type 

  @xref
    <f OtxTemuxMx13SpeCfg>

******************************************************************************/
enum OtxTemuxDs3FrameTypeE {
  OTX_TEMUX_M23   = 0,  // @emem M23  
  OTX_TEMUX_CBIT  = 1   // @emem Cbit parity
};
typedef enum OtxTemuxDs3FrameTypeE OtxTemuxDs3FrameTypeE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for Ingress data source 

  @xref
    <f OtxTemuxD3E3SpeDataPathCfg>

******************************************************************************/
enum OtxTemuxIngressSrcE {
  OTX_TEMUX_I_RX_SERIAL = 0,  // @emem Rx Serial Interface 
  OTX_TEMUX_I_DS3E3MD   = 1   // @emem DS3E3MD
};
typedef enum OtxTemuxIngressSrcE OtxTemuxIngressSrcE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for Egress data source 

  @xref
    <f OtxTemuxD3E3SpeDataPathCfg>

******************************************************************************/
enum OtxTemuxEgressSrcE {
  OTX_TEMUX_E_MX13        = 0,  // @emem MX13 
  OTX_TEMUX_E_TX_PAYLOAD  = 1,  // @emem Tx Payload Interface
  OTX_TEMUX_E_SBI         = 2   // @emem SBI Interface
};
typedef enum OtxTemuxEgressSrcE OtxTemuxEgressSrcE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for DS3/E3 framing

  @xref
    <f OtxTemuxD3E3SpeFrameCfg>

******************************************************************************/
enum OtxTemuxDs3e3FrameE {
  OTX_TEMUX_E_DS3      = 0,  // @emem DS3 - unframed/clearchannel 
  OTX_TEMUX_E_E3       = 1,  // @emem E3 - unframed/clearchannel
  OTX_TEMUX_E_DS3_CBIT = 2,  // @emem DS3 - C-bit parity
  OTX_TEMUX_E_DS3_M23  = 3,  // @emem DS3- M23 framing
  OTX_TEMUX_E_E3_G751  = 4,  // @emem E3 - G.751
  OTX_TEMUX_E_E3_G832  = 5   // @emem E3 - G.832
};
typedef enum OtxTemuxDs3e3FrameE OtxTemuxDs3e3FrameE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration format of LIU

  @xref
    <f OtxTemuxD3E3SpeLineIfCfg>

******************************************************************************/
enum OtxTemuxDs3e3ModeE {
  OTX_TEMUX_DS3      = 0,  // @emem Interface format DS3  
  OTX_TEMUX_E3       = 1   // @emem Interface format E3 
};
typedef enum OtxTemuxDs3e3ModeE OtxTemuxDs3e3ModeE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration Transmit/Receive signal polarity

  @xref
    <f OtxTemuxD3E3SpeLineIfCfg>

******************************************************************************/
enum OtxTemuxSignalPolarityE {
  OTX_TEMUX_UNIPOLAR = 0,  // @emem LIU signal polarity unipolar 
  OTX_TEMUX_BIPOLAR  = 1   // @emem LIU signal polarity bipolar 
};
typedef enum OtxTemuxSignalPolarityE OtxTemuxSignalPolarityE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for Egress DS3/E3 timing source

  @xref
    <f OtxTemuxD3E3SpeTimingCfg>
    <f OtxTemuxD3E3SpeSbiCfg>

******************************************************************************/
enum OtxTemuxTimingModeE {
  OTX_TEMUX_SBI_EGRESS     = 0,  // @emem SBI Egress Data Rate
  OTX_TEMUX_LINK_RATE      = 1,  // @emem Link Rate Octet 
  OTX_TEMUX_TICLK          = 2,  // @emem TICLK
  OTX_TEMUX_DS3E3_REF_CLK  = 3,  // @emem DS3REFCLK/E3REFCLK 
  OTX_TEMUX_DS3E3_RECOVER  = 4   // @emem DS3/E3 Recovered Clock 
};
typedef enum OtxTemuxTimingModeE OtxTemuxTimingModeE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for DS3/E3 payload frame type

  @xref
    <f OtxTemuxD3E3SpeSbiCfg>

******************************************************************************/
enum OtxTemuxPayloadE {
  OTX_TEMUX_DS3_FRAMED     = 0,  // @emem framed DS3
  OTX_TEMUX_DS3_UNFRAMED   = 1,  // @emem unframed DS3 
  OTX_TEMUX_E3_FRAMED      = 2,  // @emem framed E3
  OTX_TEMUX_E3_UNFRAMED    = 3   // @emem unframed E3 
};
typedef enum OtxTemuxPayloadE OtxTemuxPayloadE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration T1E1 Data path configuration

  @xref
    <f OtxTemuxE1T1SpeCfg>

******************************************************************************/
enum OtxTemuxSpeDestE {
  OTX_TEMUX_TRIBXC     = 0,  // @emem TRIBXC/MX13 
  OTX_TEMUX_MAPPER     = 1   // @emem Mapper 
};
typedef enum OtxTemuxSpeDestE OtxTemuxSpeDestE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration T1/E1 framing mode

  @xref
    <f OtxTemuxE1T1TribFrameCfg>

******************************************************************************/
enum OtxTemuxFrameModeE {
  OTX_TEMUX_T1_UNFRAMED = 0,  // @emem T1 Unframed
  OTX_TEMUX_T1_ESF      = 1,  // @emem T1 ESF
  OTX_TEMUX_T1_SF       = 2,  // @emem T1 SF
  OTX_TEMUX_E1_UNFRAMED = 3,  // @emem E1 Unframed
  OTX_TEMUX_E1_STANDARD = 4,  // @emem E1 Standard
  OTX_TEMUX_E1_CRC      = 5,  // @emem E1 CRC
  OTX_TEMUX_E1_CAS      = 6,  // @emem E1 CAS
  OTX_TEMUX_E1_CAS_CRC  = 7   // @emem E1 CAS + CRC
};
typedef enum OtxTemuxFrameModeE OtxTemuxFrameModeE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration ingress/egress elastic buffer

  @xref
    <f OtxTemuxE1T1IngressTribTimingCfg>
    <f OtxTemuxE1T1EgressTribTimingCfg>

******************************************************************************/
enum OtxTemuxELSTE {
  OTX_TEMUX_ELST_DATAPATH = 0,  // @emem RX_ELST/TX_ELST is in the data path
  OTX_TEMUX_ELST_BYPASSED = 1   // @emem RX_ELST/TX_ELST is bypassed
};
typedef enum OtxTemuxELSTE OtxTemuxELSTE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration ingress tributary timing mode

  @xref
    <f OtxTemuxE1T1IngressTribTimingCfg>

******************************************************************************/
enum OtxTemuxRxTimingE {
  OTX_TEMUX_RX_TT_RTDM  = 0, // @emem RTDM (bit asynchronously demapped)
  OTX_TEMUX_RX_TT_EXSBI = 1, // @emem Mapper EXSBI (byte synchronously demapped)
  OTX_TEMUX_RX_TT_MX13  = 2, // @emem MX13 (demultiplexed from DS3)
  OTX_TEMUX_RX_TT_MUX   = 3  // @emem Transmux Mode
};
typedef enum OtxTemuxRxTimingE OtxTemuxRxTimingE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration egress tributary timing mode

  @xref
    <f OtxTemuxE1T1EgressTribTimingCfg>

******************************************************************************/
enum OtxTemuxTxTimingE {
  OTX_TEMUX_TX_TT_LOOP  = 0, // @emem Loop Timing
  OTX_TEMUX_TX_TT_CTCLK = 1, // @emem CTCLK or internally recovered clock
  OTX_TEMUX_TX_TT_DSSI  = 2, // @emem Data from System Side Interface
  OTX_TEMUX_TX_TT_TISS  = 3, // @emem Timing Information from System Side interface
  OTX_TEMUX_TX_TT_MUX   = 4  // @emem Transmux Mode
};
typedef enum OtxTemuxTxTimingE OtxTemuxTxTimingE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of tributary synchronous or 
    asynchronous on SBI Add and Drop Bus

  @xref
    <f OtxTemuxE1T1TribSbiCfg>

******************************************************************************/
enum OtxTemuxSyncE {
  OTX_TEMUX_ASYNC  = 0,  // @emem asynchronous  
  OTX_TEMUX_SYNC   = 1   // @emem synchronous
};
typedef enum OtxTemuxSyncE OtxTemuxSyncE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of tributary T1/E1 or  
    Transparent Virtual Tributary (TVT) on SBI Add and Drop Bus

  @xref
    <f OtxTemuxE1T1TribSbiCfg>

******************************************************************************/
enum OtxTemuxModeE {
  OTX_TEMUX_SBI_T1E1  = 0,  // @emem T1E1 rate tributary mode 
  OTX_TEMUX_SBI_TVT   = 1   // @emem TVT mode
};
typedef enum OtxTemuxModeE OtxTemuxModeE;


/*******************************************************************************

  @struct
    Specific details for the single destination to the four sources that 
    were passed to the OtxTemuxStsiDestPortCfg function.

  @xref
    <f OtxTemuxGetInfo>
    <t OtxTemuxGetTemuxInfoS>
    <f OtxTemuxStsiDestPortCfg>

*******************************************************************************/
struct OtxTemuxStsiDestSrcS {
  OtxTemuxDestPortE  eDataLinkDestination;                // @field Destination
  OtxTemuxSrcPortE   eDataLinkSource[OTX_TEMUX_MAX_LINK]; // @field Source
};
typedef struct OtxTemuxStsiDestSrcS OtxTemuxStsiDestSrcS;

/*******************************************************************************

  @struct
    Specific details for the subsystem data path configuration that 
    were passed to the OtxTemuxSysIfModeCfg function.

  @xref
    <f OtxTemuxGetInfo>
    <f OtxTemuxSysIfModeCfg>

*******************************************************************************/
struct OtxTemuxSysIfModeS {
  OtxTemuxSysIfModeE eSysIfMode; // @field System side (0-SBI 1-SBI-TR 2-HMVIP)
  OTX_BOOL           nParam[5];  // @field parameters 1-5
};
typedef struct OtxTemuxSysIfModeS OtxTemuxSysIfModeS;

/*******************************************************************************

  @struct
    Specific details of the current Line Interface (Li) Devices status. 
      LOS - Loss of signal
      LOF - Loss of frame sync
      TIM - Trace Identifier Mismatch
      SF - Signal Failure
      SD - Signal Degrade
      AIS - Alarm Indication Signal defect

  @xref
    <f OtxTemuxGetLiStatus>
    <t OtxTemuxVtTypeE>

*******************************************************************************/
struct OtxTemuxGetLiStatusS {
  OTX_BOOL          bLineStatus; // @field 1-OK,  0-Check errors below
  OTX_BOOL          bLOS;        // @field 1-LOS, 0-no error
  OTX_BOOL          bLOF;        // @field 1-LOF, 0-no error
  OTX_BOOL          bTIM;        // @field 1-TIM, 0-no error
  OTX_BOOL          bSF;         // @field 1-SF,  0-no error
  OTX_BOOL          bSD;         // @field 1-SD,  0-no error
  OTX_BOOL          bAIS;        // @field 1-AIS, 0-no error
};
typedef struct OtxTemuxGetLiStatusS OtxTemuxGetLiStatusS;

/*******************************************************************************

  @struct
    Specific details of the Temux device used to display a configuration
    of the device after the device is configured during the user configuration.

    Note this is mainly used for debug.

  @xref
    <f OtxTemuxGetInfo>

*******************************************************************************/
struct OtxTemuxGetTemuxInfoS {
  OTX_UINT32            nNumSpans;                                             // @field Number of spans supported 
  OTX_BOOL              bClockConfig[OTX_TEMUX_MAX_LINK];                      // @field SONET/SDH Clock is configured
  OtxTemuxClockSrcE     eClkSrcMode[OTX_TEMUX_MAX_LINK];                       // @field OtxTemuxClockSrcE
  OtxTemuxDataLinkSrcE  eDataLinkSource[OTX_TEMUX_MAX_LINK];                   // @field OtxTemuxDataLinkSrcE
  OtxTemuxIntfModeE     eIntfMode;                                             // @field Physical interface used
  OtxTemuxLinkSrcE      eLinkSrc[OTX_TEMUX_MAX_LINK];                          // @field Working and protect line side 
  OtxTemuxSts12ConcatE  eSts12Concatenation[OTX_TEMUX_MAX_LINK];               // @field Payload configuration
  OtxTemuxSts3ConcatE   eSts3Concatenation[OTX_TEMUX_MAX_LINK];                // @field Payload configuration
  OtxTemuxStsiDestSrcS  sStreamConnection[OTX_TEMUX_MAX_LINK];                 // @field Destination to source
  OtxTemuxSts12PayloadE eSts12Payload;                                         // @field OtxTemuxSts12PayloadE
  OtxTemuxDevConfigureE eConfigMode;                                           // @field Configuration mode 
  OtxTemuxInterfaceE    eHwInterface;                                          // @field SBI or HMVIP
  OtxTemuxSts1PayloadE  eSts1Payload[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];  
  OtxTemuxVtTypeE       eVtGroupPayload[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_VTGROUP];
  OtxTemuxSysIfModeS    sStsiDestSrc;
  OtxTemuxSysIfModeE    eSysIfMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxSpeDestE      eSpeDest[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxPhdTribE      ePhdTribType[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxMapSpeSrcE    eMapSpeSrc[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxFrameModeE    eFrameMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxELSTE         eBypassModeIngress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxRxTimingE     eTimingIngress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxELSTE         eBypassModeEgress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxTxTimingE     eTimingEgress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxMapTribModeE  eSrcOrDestEgress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxMapTribModeE  eMapTribMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxPhdTribE      eMapPhdTribType[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxVtTypeE       eMapSonetTribType[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxSyncE         eT1E1SyncTrib[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OTX_BOOL              bT1E1Enable[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxModeE         eT1E1RateMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
};
typedef struct OtxTemuxGetTemuxInfoS OtxTemuxGetTemuxInfoS;

/*******************************************************************************

  @struct
    Specific details of the DS1 (T1) framer status. 
      INF  - 1 inframe, 0 out of frame
      COFA - 1 framing bit position changed, 0 no change of framing bit position
      YEL  - Yellow alarm
      RED  - Red alarm
      AIS  - Alarm Indication Signal defect

  @xref
    <f OtxTemuxGetDs1Status>

*******************************************************************************/
struct OtxTemuxGetDs1S {
  OTX_BOOL          bINF;   // @field 1-Inframe, 0-Out of frame
  OTX_BOOL          bCOFA;  // @field 1-Framing bit position changed 
                            //<nl> 0-No change of framing bit position
  OTX_BOOL          bYEL;   // @field 1-Yellow alarm, 0-No alarm
  OTX_BOOL          bRED;   // @field 1-Red alarm, 0-No alarm
  OTX_BOOL          bAIS;   // @field 1-AIS alarm, 0-No alarm
};
typedef struct OtxTemuxGetDs1S OtxTemuxGetDs1S;

/*******************************************************************************

  @struct
    Specific details of the E1 framer status. 
      TS16AISD - Timeslot 16 Alarm Indication Signal detect
      AIS      - Alarm Indication Signal defect
      RED      - Red alarm
      AISD     - AIS state over a 40ms period
      RMAI     - Remote multi-frame alarm indication updated every 16 frames
      RAI      - Remote alarm indication updated every two frames
      CFEBE    - State of the continuous FEBE indicator
      RAICCRC  - State of the RAI
      OOOF     - Out of offline frame indicator
      INCMF    - CRC multi-frame alignment
      INSMF    - Signaling multi-frame alignment
      INF      - 1 inframe, 0 out of frame

  @xref
    <f OtxTemuxGetE1Status>

*******************************************************************************/
struct OtxTemuxGetE1S {
  OTX_BOOL bTS16AISD; // @field 1-TS16 data stream has a low 0-bit density. 
                      // TS16AISD is detected when the incoming TS16 signal 
                      // has less three 0 in each of 2 consecutive multi-frames.
                      //<nl> 0-TS16 data stream does not have a low 0-bit density.
  OTX_BOOL bAIS;      // @field 1-AIS alarm, 0-no alarm
  OTX_BOOL bRED;      // @field 1-Red alarm,  0-no alarm
  OTX_BOOL bAISD;     // @field 1-AIS condition has been detected.
                      //<nl> 0-No AIS condition has been detected.
  OTX_BOOL bRMAI;     // @field 1-The Y bit (bit 6 in time slot 16 in 
                      // frame 0 of the signaling multi-frames) has been 
                      // a logic one for 3 consecutive signaling multi-frames.
                      //<nl> 0-No remote multi-frame alarm indication has 
                      // been received.
  OTX_BOOL bRAI;      // @field 1-A bit (bit 3 in time slot 0 of the non-frame 
                      // alignment signal frame) has been logic 1 for an interval
                      // specified by the RAIC bit. When the RAIC bit is 1, RAI 
                      // is set when A=1 for 4 or more consecutive intervals. 
                      // When the RAIC bit is a logic 0, RAI is set when A=1.
                      //<nl> 0-A bit has been logic 0 for at least one interval.
  OTX_BOOL bCFEBE;    // @field 1-CRC error (E bit) is set high on more than 
                      // 990 occasions in each second (out of 1000 occasions) 
                      // for the last 5 consecutive seconds. 
                      //<nl> 0-CRC error is not set high on more than 990 
                      // occasions in each second for the last 5 consecutive seconds.
  OTX_BOOL bRAICCRC;  // @field 1-Remote alarm (A bit) is set high and the CRC error
                      // (E bit) has been low for a period of 10 ms.
                      //<nl> 0-Remote alarm is not set high or the CRC error has not
                      // been low for a period of 10 ms.
  OTX_BOOL bOOOF;     // @field 1-Offline framer in the CRC multi-frame find 
                      // procedure is searching for frame alignment.
                      //<nl> 0-Frame alignment has been found.
  OTX_BOOL bINCMF;    // @field 1-CRC multi-frame alignment has been found. 
                      //<nl> 0-CRC multi-frame alignment has been lost.
  OTX_BOOL bINSMF;    // @field 1-Signalling multi-frame alignment has been found.
                      //<nl> 0-Signalling multi-frame alignment has been lost.
  OTX_BOOL bINF;      // @field 1-inframe, 0-out of frame
};
typedef struct OtxTemuxGetE1S OtxTemuxGetE1S;

#ifdef __cplusplus
}// extern "C"
#endif



/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2010-2011

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif  // OTX_TEMUX_DEF_H
